@@ -159,6 +159,10 @@ uint FileChooserPortal::OpenFile(const QDBusObjectPath &handle,
     parseFilters(options, nameFilters, mimeTypeFilters, allFilters, selectedMimeTypeFilter);
 
     // open directory
+    if (options.contains(QStringLiteral("directory"))) {
+        directory = options.value("directory").toBool();
+    }
+
     if (directory && !options.contains(QStringLiteral("choices"))) {
         QFileDialog dirDialog;
         dirDialog.setWindowTitle(title);
@@ -196,6 +200,11 @@ uint FileChooserPortal::OpenFile(const QDBusObjectPath &handle,
         OptionList optionList = qdbus_cast<OptionList>(options.value(QStringLiteral("choices")));
         //        optionsWidget.reset(CreateChoiceControls(optionList, checkboxes, comboboxes));
     }
+
+    if (options.contains(QStringLiteral("multiple"))) {
+        multiple = options.value("multiple").toBool();
+    }
+
     QFileDialog fileDialog;
     Utils::setParentWindow(&fileDialog, parent_window);
     auto request = new Request(handle, QVariant(), &fileDialog);
