@@ -5,6 +5,7 @@
 #pragma once
 
 #include "protocols/screencopy.h"
+#include "protocols/treelandcapture.h"
 
 #include <QDBusContext>
 #include <private/qwaylanddisplay_p.h>
@@ -16,6 +17,9 @@ class PortalWaylandContext : public QObject, public QDBusContext
 public:
     PortalWaylandContext(QObject *parent = nullptr);
     inline QPointer<ScreenCopyManager> screenCopyManager() { return m_screenCopyManager; }
+    inline QPointer<TreeLandCaptureManager> treelandCaptureManager()  { return m_treelandCaptureManager; }
+
 private:
     ScreenCopyManager *m_screenCopyManager;
+    TreeLandCaptureManager *m_treelandCaptureManager;
 };
